@@ -16,7 +16,7 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.468';
+$VERSION = '3.470';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
@@ -81,7 +81,7 @@ sub parameter_file {
     my $hold_fileline = $self->fileline();
     while (my $line = $fh->getline()) {
 	chomp $line;
-	$line =~ s/\/\/.*$//;
+	$line =~ s/(?:^|\s)\/\/.*$//;
 	next if $line =~ /^\s*$/;
 	$self->fileline("$filename:$.");
 	my @p = (split /\s+/,"$line ");
@@ -795,7 +795,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2020 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
